@@ -4,9 +4,9 @@ import (
 	"os"
 	"strings"
 
-	"github.com/git-lfs/git-lfs/git"
-	"github.com/git-lfs/git-lfs/lfs"
-	"github.com/git-lfs/git-lfs/tools/humanize"
+	"github.com/git-lfs/git-lfs/v3/git"
+	"github.com/git-lfs/git-lfs/v3/lfs"
+	"github.com/git-lfs/git-lfs/v3/tools/humanize"
 	"github.com/spf13/cobra"
 )
 
@@ -68,6 +68,10 @@ func lsFilesCommand(cmd *cobra.Command, args []string) {
 			return
 		}
 
+		if p.Size == 0 {
+			return
+		}
+
 		if !lsFilesScanAll && !scanRange {
 			if _, ok := seen[p.Name]; ok {
 				return
