@@ -6,10 +6,10 @@ import (
 	"io"
 	"strings"
 
-	"github.com/git-lfs/git-lfs/errors"
-	"github.com/git-lfs/git-lfs/git"
-	"github.com/git-lfs/git-lfs/git/githistory"
-	"github.com/git-lfs/git-lfs/tasklog"
+	"github.com/git-lfs/git-lfs/v3/errors"
+	"github.com/git-lfs/git-lfs/v3/git"
+	"github.com/git-lfs/git-lfs/v3/git/githistory"
+	"github.com/git-lfs/git-lfs/v3/tasklog"
 	"github.com/git-lfs/gitobj/v2"
 	"github.com/spf13/cobra"
 )
@@ -331,7 +331,7 @@ func ensureWorkingCopyClean(in io.Reader, out io.Writer) {
 		answer := bufio.NewReader(in)
 	L:
 		for {
-			fmt.Fprintf(out, "migrate: override changes in your working copy? [Y/n] ")
+			fmt.Fprintf(out, "migrate: override changes in your working copy?  All uncommitted changes will be lost! [y/N] ")
 			s, err := answer.ReadString('\n')
 			if err != nil {
 				if err == io.EOF {
@@ -342,10 +342,10 @@ func ensureWorkingCopyClean(in io.Reader, out io.Writer) {
 			}
 
 			switch strings.TrimSpace(s) {
-			case "n", "N":
+			case "n", "N", "":
 				proceed = false
 				break L
-			case "y", "Y", "":
+			case "y", "Y":
 				proceed = true
 				break L
 			}
@@ -368,6 +368,8 @@ func init() {
 	info.Flags().IntVar(&migrateInfoTopN, "top", 5, "--top=<n>")
 	info.Flags().StringVar(&migrateInfoAboveFmt, "above", "", "--above=<n>")
 	info.Flags().StringVar(&migrateInfoUnitFmt, "unit", "", "--unit=<unit>")
+	info.Flags().StringVar(&migrateInfoPointers, "pointers", "", "Ignore, dereference, or include LFS pointer files")
+	info.Flags().BoolVar(&migrateFixup, "fixup", false, "Infer filepaths based on .gitattributes")
 
 	importCmd := NewCommand("import", migrateImportCommand)
 	importCmd.Flags().StringVar(&migrateImportAboveFmt, "above", "", "--above=<n>")
