@@ -6,7 +6,7 @@ import (
 	"testing"
 
 	"github.com/git-lfs/gitobj/v2"
-	"github.com/git-lfs/wildmatch"
+	"github.com/git-lfs/wildmatch/v2"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 )
