@@ -10,13 +10,13 @@ import (
 	"sync"
 	"time"
 
-	"github.com/git-lfs/git-lfs/config"
-	"github.com/git-lfs/git-lfs/errors"
-	"github.com/git-lfs/git-lfs/filepathfilter"
-	"github.com/git-lfs/git-lfs/git"
-	"github.com/git-lfs/git-lfs/lfsapi"
-	"github.com/git-lfs/git-lfs/tools"
-	"github.com/git-lfs/git-lfs/tools/kv"
+	"github.com/git-lfs/git-lfs/v3/config"
+	"github.com/git-lfs/git-lfs/v3/errors"
+	"github.com/git-lfs/git-lfs/v3/filepathfilter"
+	"github.com/git-lfs/git-lfs/v3/git"
+	"github.com/git-lfs/git-lfs/v3/lfsapi"
+	"github.com/git-lfs/git-lfs/v3/tools"
+	"github.com/git-lfs/git-lfs/v3/tools/kv"
 	"github.com/rubyist/tracerx"
 )
 
@@ -42,7 +42,7 @@ type LockCacher interface {
 type Client struct {
 	Remote    string
 	RemoteRef *git.Ref
-	client    *lockClient
+	client    lockClient
 	cache     LockCacher
 	cacheDir  string
 	cfg       *config.Configuration
@@ -63,7 +63,7 @@ type Client struct {
 func NewClient(remote string, lfsClient *lfsapi.Client, cfg *config.Configuration) (*Client, error) {
 	return &Client{
 		Remote:             remote,
-		client:             &lockClient{Client: lfsClient},
+		client:             newGenericLockClient(lfsClient),
 		cache:              &nilLockCacher{},
 		cfg:                cfg,
 		ModifyIgnoredFiles: lfsClient.GitEnv().Bool("lfs.lockignoredfiles", false),
@@ -112,7 +112,7 @@ func (c *Client) LockFile(path string) (Lock, error) {
 		if len(lockRes.RequestID) > 0 {
 			tracerx.Printf("Server Request ID: %s", lockRes.RequestID)
 		}
-		return Lock{}, fmt.Errorf("Server unable to create lock: %s", lockRes.Message)
+		return Lock{}, fmt.Errorf("server unable to create lock: %s", lockRes.Message)
 	}
 
 	lock := *lockRes.Lock
@@ -125,9 +125,11 @@ func (c *Client) LockFile(path string) (Lock, error) {
 		return Lock{}, errors.Wrap(err, "make lockpath absolute")
 	}
 
-	// Ensure writeable on return
-	if err := tools.SetFileWriteFlag(abs, true); err != nil {
-		return Lock{}, err
+	// If the file exists, ensure that it's writeable on return
+	if tools.FileExists(abs) {
+		if err := tools.SetFileWriteFlag(abs, true); err != nil {
+			return Lock{}, errors.Wrap(err, "set file write flag")
+		}
 	}
 
 	return lock, nil
@@ -154,7 +156,7 @@ func getAbsolutePath(p string) (string, error) {
 func (c *Client) UnlockFile(path string, force bool) error {
 	id, err := c.lockIdFromPath(path)
 	if err != nil {
-		return fmt.Errorf("Unable to get lock id: %v", err)
+		return fmt.Errorf("unable to get lock id: %v", err)
 	}
 
 	return c.UnlockFileById(id, force)
@@ -172,11 +174,11 @@ func (c *Client) UnlockFileById(id string, force bool) error {
 		if len(unlockRes.RequestID) > 0 {
 			tracerx.Printf("Server Request ID: %s", unlockRes.RequestID)
 		}
-		return fmt.Errorf("Server unable to unlock: %s", unlockRes.Message)
+		return fmt.Errorf("server unable to unlock: %s", unlockRes.Message)
 	}
 
 	if err := c.cache.RemoveById(id); err != nil {
-		return fmt.Errorf("Error caching unlock information: %v", err)
+		return fmt.Errorf("error caching unlock information: %v", err)
 	}
 
 	if unlockRes.Lock != nil {
@@ -268,14 +270,12 @@ func (c *Client) SearchLocksVerifiable(limit int, cached bool) (ourLocks, theirL
 		c.cache.Clear()
 
 		for {
-			list, res, err := c.client.SearchVerifiable(c.Remote, body)
-			if res != nil {
-				switch res.StatusCode {
-				case http.StatusNotFound, http.StatusNotImplemented:
-					return ourLocks, theirLocks, errors.NewNotImplementedError(err)
-				case http.StatusForbidden:
-					return ourLocks, theirLocks, errors.NewAuthError(err)
-				}
+			list, status, err := c.client.SearchVerifiable(c.Remote, body)
+			switch status {
+			case http.StatusNotFound, http.StatusNotImplemented:
+				return ourLocks, theirLocks, errors.NewNotImplementedError(err)
+			case http.StatusForbidden:
+				return ourLocks, theirLocks, errors.NewAuthError(err)
 			}
 
 			if err != nil {
@@ -286,7 +286,7 @@ func (c *Client) SearchLocksVerifiable(limit int, cached bool) (ourLocks, theirL
 				if len(list.RequestID) > 0 {
 					tracerx.Printf("Server Request ID: %s", list.RequestID)
 				}
-				return ourLocks, theirLocks, fmt.Errorf("Server error searching locks: %s", list.Message)
+				return ourLocks, theirLocks, fmt.Errorf("server error searching locks: %s", list.Message)
 			}
 
 			for _, l := range list.Ours {
@@ -367,7 +367,7 @@ func (c *Client) searchRemoteLocks(filter map[string]string, limit int) ([]Lock,
 			if len(list.RequestID) > 0 {
 				tracerx.Printf("Server Request ID: %s", list.RequestID)
 			}
-			return locks, fmt.Errorf("Server error searching for locks: %s", list.Message)
+			return locks, fmt.Errorf("server error searching for locks: %s", list.Message)
 		}
 
 		for _, l := range list.Locks {
@@ -393,7 +393,7 @@ func (c *Client) searchRemoteLocks(filter map[string]string, limit int) ([]Lock,
 //
 // If the API call failed, an error will be returned. If multiple locks matched
 // the given path (should not happen during real-world usage), an error will be
-// returnd. If no locks matched the given path, an error will be returned.
+// returned. If no locks matched the given path, an error will be returned.
 //
 // If the API call is successful, and only one lock matches the given filepath,
 // then its ID will be returned, along with a value of "nil" for the error.
