@@ -327,10 +327,10 @@ begin_test "ls-files: --all with argument(s)"
   git init "$reponame"
   cd "$reponame"
 
-  git lfs ls-files --all master 2>&1 | tee ls-files.log
+  git lfs ls-files --all main 2>&1 | tee ls-files.log
 
   if [ "0" -eq "${PIPESTATUS[0]}" ]; then
-    echo >&2 "fatal: \`git lfs ls-files --all master\` to fail"
+    echo >&2 "fatal: \`git lfs ls-files --all main\` to fail"
     exit 1
   fi
 
@@ -497,4 +497,22 @@ begin_test "ls-files: history with reference range"
   [ 0 -eq $(grep -c "b\.dat" ls-files.log) ]
   [ 0 -eq $(grep -c "c\.dat" ls-files.log) ]
 )
+end_test
+
+begin_test "ls-files: not affected by lfs.fetchexclude"
+(
+  set -e
+
+  mkdir repo-fetchexclude
+  cd repo-fetchexclude
+  git init
+  git lfs track "*.dat" | grep "Tracking \"\*.dat\""
+  echo "some data" > some.dat
+  echo "some text" > some.txt
+  echo "missing" > missing.dat
+  git add missing.dat
+  git commit -m "add missing file"
+  git config lfs.fetchexclude '*'
+  [ "6bbd052ab0 * missing.dat" = "$(git lfs ls-files)" ]
+)
 end_test
\ No newline at end of file
