@@ -11,7 +11,6 @@ begin_test "ssh with proxy command in lfs.url"
   clone_repo "$reponame" "$reponame"
 
   sshurl="${GITSERVER/http:\/\//ssh://-oProxyCommand=ssh-proxy-test/}/$reponame"
-  echo $sshurl
   git config lfs.url "$sshurl"
 
   contents="test"
@@ -21,13 +20,13 @@ begin_test "ssh with proxy command in lfs.url"
   git add .gitattributes test.dat
   git commit -m "initial commit"
 
-  git push origin master 2>&1 | tee push.log
+  GIT_TRACE=1 git push origin main 2>&1 | tee push.log
   if [ "0" -eq "${PIPESTATUS[0]}" ]; then
     echo >&2 "fatal: push succeeded"
     exit 1
   fi
 
-  grep "got 4 args" push.log
+  grep 'expected.*git@127.0.0.1' push.log
   grep "lfs-ssh-echo -- -oProxyCommand" push.log
 )
 end_test
