@@ -1,3 +1,4 @@
+//go:build windows
 // +build windows
 
 package tools
@@ -6,7 +7,7 @@ import (
 	"bytes"
 	"fmt"
 
-	"github.com/git-lfs/git-lfs/subprocess"
+	"github.com/git-lfs/git-lfs/v3/subprocess"
 )
 
 type cygwinSupport byte
