@@ -16,8 +16,8 @@ import (
 	"sync"
 	"sync/atomic"
 
-	"github.com/git-lfs/git-lfs/errors"
-	"github.com/git-lfs/git-lfs/filepathfilter"
+	"github.com/git-lfs/git-lfs/v3/errors"
+	"github.com/git-lfs/git-lfs/v3/filepathfilter"
 )
 
 // FileOrDirExists determines if a file/dir exists, returns IsDir() results too.
@@ -60,7 +60,7 @@ func ResolveSymlinks(path string) string {
 		return path
 	}
 
-	if resolved, err := filepath.EvalSymlinks(path); err == nil {
+	if resolved, err := CanonicalizeSystemPath(path); err == nil {
 		return resolved
 	}
 	return path
@@ -285,8 +285,8 @@ type fastWalker struct {
 // rootDir - Absolute path to the top of the repository working directory
 func fastWalkWithExcludeFiles(rootDir string) *fastWalker {
 	excludePaths := []filepathfilter.Pattern{
-		filepathfilter.NewPattern(".git"),
-		filepathfilter.NewPattern("**/.git"),
+		filepathfilter.NewPattern(".git", filepathfilter.GitIgnore),
+		filepathfilter.NewPattern("**/.git", filepathfilter.GitIgnore),
 	}
 
 	limit, _ := strconv.Atoi(os.Getenv("LFS_FASTWALK_LIMIT"))
@@ -494,7 +494,7 @@ func CanonicalizePath(path string, missingOk bool) (string, error) {
 		if err != nil {
 			return "", err
 		}
-		result, err := filepath.EvalSymlinks(path)
+		result, err := CanonicalizeSystemPath(path)
 		if err != nil && os.IsNotExist(err) && missingOk {
 			return path, nil
 		}
