@@ -7,20 +7,21 @@ import (
 	"sync"
 	"time"
 
-	"github.com/git-lfs/git-lfs/errors"
-	"github.com/git-lfs/git-lfs/git"
-	"github.com/git-lfs/git-lfs/lfsapi"
-	"github.com/git-lfs/git-lfs/lfshttp"
-	"github.com/git-lfs/git-lfs/tools"
+	"github.com/git-lfs/git-lfs/v3/errors"
+	"github.com/git-lfs/git-lfs/v3/git"
+	"github.com/git-lfs/git-lfs/v3/lfshttp"
+	"github.com/git-lfs/git-lfs/v3/tools"
 	"github.com/rubyist/tracerx"
 )
 
 const (
 	defaultBatchSize = 100
+	baseRetryDelayMs = 250
 )
 
 type retryCounter struct {
-	MaxRetries int `git:"lfs.transfer.maxretries"`
+	MaxRetries    int
+	MaxRetryDelay int
 
 	// cmu guards count
 	cmu sync.Mutex
@@ -28,26 +29,23 @@ type retryCounter struct {
 	count map[string]int
 }
 
-// newRetryCounter instantiates a new *retryCounter. It parses the gitconfig
-// value: `lfs.transfer.maxretries`, and falls back to defaultMaxRetries if none
-// was provided.
-//
-// If it encountered an error in Unmarshaling the *config.Configuration, it will
-// be returned, otherwise nil.
+// newRetryCounter instantiates a new *retryCounter.
 func newRetryCounter() *retryCounter {
 	return &retryCounter{
-		MaxRetries: defaultMaxRetries,
-		count:      make(map[string]int),
+		MaxRetries:    defaultMaxRetries,
+		MaxRetryDelay: defaultMaxRetryDelay,
+		count:         make(map[string]int),
 	}
 }
 
-// Increment increments the number of retries for a given OID. It is safe to
-// call across multiple goroutines.
-func (r *retryCounter) Increment(oid string) {
+// Increment increments the number of retries for a given OID and returns the
+// new value. It is safe to call across multiple goroutines.
+func (r *retryCounter) Increment(oid string) int {
 	r.cmu.Lock()
 	defer r.cmu.Unlock()
 
 	r.count[oid]++
+	return r.count[oid]
 }
 
 // CountFor returns the current number of retries for a given OID. It is safe to
@@ -66,6 +64,22 @@ func (r *retryCounter) CanRetry(oid string) (int, bool) {
 	return count, count < r.MaxRetries
 }
 
+// ReadyTime returns the time from now when the current retry can occur or the
+// zero time if the retry can occur immediately.
+func (r *retryCounter) ReadyTime(oid string) time.Time {
+	count := r.CountFor(oid)
+	if count < 1 {
+		return time.Time{}
+	}
+
+	maxDelayMs := 1000 * uint64(r.MaxRetryDelay)
+	delay := uint64(baseRetryDelayMs) * (1 << uint(count-1))
+	if delay == 0 || delay > maxDelayMs {
+		delay = maxDelayMs
+	}
+	return time.Now().Add(time.Duration(delay) * time.Millisecond)
+}
+
 // batch implements the sort.Interface interface and enables sorting on a slice
 // of `*Transfer`s by object size.
 //
@@ -295,7 +309,8 @@ func NewTransferQueue(dir Direction, manifest *Manifest, remote string, options
 	}
 
 	q.rc.MaxRetries = q.manifest.maxRetries
-	q.client.MaxRetries = q.manifest.maxRetries
+	q.rc.MaxRetryDelay = q.manifest.maxRetryDelay
+	q.client.SetMaxRetries(q.manifest.maxRetries)
 
 	if q.batchSize <= 0 {
 		q.batchSize = defaultBatchSize
@@ -324,7 +339,12 @@ func NewTransferQueue(dir Direction, manifest *Manifest, remote string, options
 //
 // Only one file will be transferred to/from the Path element of the first
 // transfer.
-func (q *TransferQueue) Add(name, path, oid string, size int64, missing bool) {
+func (q *TransferQueue) Add(name, path, oid string, size int64, missing bool, err error) {
+	if err != nil {
+		q.errorc <- err
+		return
+	}
+
 	t := &objectTuple{
 		Name:    name,
 		Path:    path,
@@ -501,6 +521,24 @@ func (q *TransferQueue) enqueueAndCollectRetriesFor(batch batch) (batch, error)
 	next := q.makeBatch()
 	tracerx.Printf("tq: sending batch of size %d", len(batch))
 
+	enqueueRetry := func(t *objectTuple, err error, readyTime *time.Time) {
+		count := q.rc.Increment(t.Oid)
+
+		if readyTime == nil {
+			t.ReadyTime = q.rc.ReadyTime(t.Oid)
+		} else {
+			t.ReadyTime = *readyTime
+		}
+		delay := time.Until(t.ReadyTime).Seconds()
+
+		var errMsg string
+		if err != nil {
+			errMsg = fmt.Sprintf(": %s", err)
+		}
+		tracerx.Printf("tq: enqueue retry #%d after %.2fs for %q (size: %d)%s", count, delay, t.Oid, t.Size, errMsg)
+		next = append(next, t)
+	}
+
 	q.meter.Pause()
 	var bRes *BatchResponse
 	if q.manifest.standaloneTransferAgent != "" {
@@ -519,26 +557,30 @@ func (q *TransferQueue) enqueueAndCollectRetriesFor(batch batch) (batch, error)
 		var err error
 		bRes, err = Batch(q.manifest, q.direction, q.remote, q.ref, batch.ToTransfers())
 		if err != nil {
+			var hasNonScheduledErrors = false
 			// If there was an error making the batch API call, mark all of
 			// the objects for retry, and return them along with the error
 			// that was encountered. If any of the objects couldn't be
 			// retried, they will be marked as failed.
 			for _, t := range batch {
 				if q.canRetryObject(t.Oid, err) {
-					q.rc.Increment(t.Oid)
-
-					next = append(next, t)
+					hasNonScheduledErrors = true
+					enqueueRetry(t, err, nil)
 				} else if readyTime, canRetry := q.canRetryObjectLater(t.Oid, err); canRetry {
-					tracerx.Printf("tq: retrying object %s after %s seconds.", t.Oid, time.Until(readyTime).Seconds())
-					err = nil
-					t.ReadyTime = readyTime
-					next = append(next, t)
+					enqueueRetry(t, err, &readyTime)
 				} else {
+					hasNonScheduledErrors = true
 					q.wait.Done()
 				}
 			}
 
-			return next, errors.NewRetriableError(err)
+			// Only return error and mark operation as failure if at least one object
+			// was not enqueued for retrial at a later point.
+			if hasNonScheduledErrors {
+				return next, errors.NewRetriableError(err)
+			} else {
+				return next, nil
+			}
 		}
 	}
 
@@ -594,13 +636,8 @@ func (q *TransferQueue) enqueueAndCollectRetriesFor(batch batch) (batch, error)
 			tr := newTransfer(o, objects.First().Name, objects.First().Path)
 
 			if a, err := tr.Rel(q.direction.String()); err != nil {
-				// XXX(taylor): duplication
 				if q.canRetryObject(tr.Oid, err) {
-					q.rc.Increment(tr.Oid)
-					count := q.rc.CountFor(tr.Oid)
-
-					tracerx.Printf("tq: enqueue retry #%d for %q (size: %d): %s", count, tr.Oid, tr.Size, err)
-					next = append(next, objects.First())
+					enqueueRetry(objects.First(), err, nil)
 				} else {
 					q.errorc <- errors.Errorf("[%v] %v", tr.Name, err)
 
@@ -619,12 +656,7 @@ func (q *TransferQueue) enqueueAndCollectRetriesFor(batch batch) (batch, error)
 
 	retries := q.addToAdapter(bRes.endpoint, toTransfer)
 	for t := range retries {
-		q.rc.Increment(t.Oid)
-		count := q.rc.CountFor(t.Oid)
-
-		tracerx.Printf("tq: enqueue retry #%d for %q (size: %d)", count, t.Oid, t.Size)
-
-		next = append(next, t)
+		enqueueRetry(t, nil, nil)
 	}
 
 	return next, nil
@@ -881,10 +913,6 @@ func (q *TransferQueue) ensureAdapterBegun(e lfshttp.Endpoint) error {
 func (q *TransferQueue) toAdapterCfg(e lfshttp.Endpoint) AdapterConfig {
 	apiClient := q.manifest.APIClient()
 	concurrency := q.manifest.ConcurrentTransfers()
-	access := apiClient.Endpoints.AccessFor(e.Url)
-	if access.Mode() == lfsapi.NTLMAccess {
-		concurrency = 1
-	}
 
 	return &adapterConfig{
 		concurrentTransfers: concurrency,
@@ -923,6 +951,10 @@ func (q *TransferQueue) Wait() {
 	q.meter.Flush()
 	q.errorwait.Wait()
 
+	if q.manifest.sshTransfer != nil {
+		q.manifest.sshTransfer.Shutdown()
+	}
+
 	if q.unsupportedContentType {
 		for _, line := range contentTypeWarning {
 			fmt.Fprintf(os.Stderr, "info: %s\n", line)
